@@ -648,13 +648,18 @@ To automatically trust this fingerprint for future connections, click Yes. To re
     <name>QObject</name>
     <message>
         <location filename="src/MainWindow.cpp" line="60"/>
-        <source>Barrier Configurations (*.sgc);;All files (*.*)</source>
-        <translation type="finished">Cyfluniadau Barrier (*.sgc);;Pob ffeil (*.*)</translation>
+        <source>All files (*.*)</source>
+        <translation type="finished">Pob ffeil (*.*)</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="60"/>
+        <source>Barrier Configurations (*.sgc)</source>
+        <translation type="finished">Cyfluniadau Barrier (*.sgc)</translation>
     </message>
     <message>
         <location filename="src/MainWindow.cpp" line="67"/>
-        <source>Barrier Configurations (*.conf);;All files (*.*)</source>
-        <translation type="finished">Cyfluniadau Barrier (*.conf);;Pob ffeil (*.*)</translation>
+        <source>Barrier Configurations (*.conf)</source>
+        <translation type="finished">Cyfluniadau Barrier (*.conf)</translation>
     </message>
     <message>
         <location filename="src/main.cpp" line="119"/>
