@@ -648,13 +648,18 @@ To automatically trust this fingerprint for future connections, click Yes. To re
     <name>QObject</name>
     <message>
         <location filename="src/MainWindow.cpp" line="60"/>
-        <source>Barrier Configurations (*.sgc);;All files (*.*)</source>
-        <translation type="finished">Конфигурация Barrier (*.sgc);;Все файлы (*.*)</translation>
+        <source>All files (*.*)</source>
+        <translation type="finished">Все файлы (*.*)</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="60"/>
+        <source>Barrier Configurations (*.sgc)</source>
+        <translation type="finished">Конфигурация Barrier (*.sgc)</translation>
     </message>
     <message>
         <location filename="src/MainWindow.cpp" line="67"/>
-        <source>Barrier Configurations (*.conf);;All files (*.*)</source>
-        <translation type="finished">Конфигурация Barrier (*.conf);;Все файлы (*.*)</translation>
+        <source>Barrier Configurations (*.conf)</source>
+        <translation type="finished">Конфигурация Barrier (*.conf)</translation>
     </message>
     <message>
         <location filename="src/main.cpp" line="119"/>
@@ -1320,7 +1325,7 @@ p, li { white-space: pre-wrap; }
         <source>Login failed, an error occurred.
 
 %1</source>
-        <translation type="finished">Войти не удалось, произошла ошибка. 
+        <translation type="finished">Войти не удалось, произошла ошибка.
 
 %1</translation>
     </message>
@@ -1331,7 +1336,7 @@ p, li { white-space: pre-wrap; }
 Server response:
 
 %1</source>
-        <translation type="finished">Войти не удалось, произошла ошибка. 
+        <translation type="finished">Войти не удалось, произошла ошибка.
 
 Ответ сервера:
 
