@@ -648,13 +648,18 @@ To automatically trust this fingerprint for future connections, click Yes. To re
     <name>QObject</name>
     <message>
         <location filename="src/MainWindow.cpp" line="60"/>
-        <source>Barrier Configurations (*.sgc);;All files (*.*)</source>
-        <translation type="finished">Konfiguracioni i Barrier  (*.sgc);;Te gjithe  (*.*)</translation>
+        <source>All files (*.*)</source>
+        <translation type="finished">Te gjithe (*.*)</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="60"/>
+        <source>Barrier Configurations (*.sgc)</source>
+        <translation type="finished">Konfiguracioni i Barrier (*.sgc)</translation>
     </message>
     <message>
         <location filename="src/MainWindow.cpp" line="67"/>
-        <source>Barrier Configurations (*.conf);;All files (*.*)</source>
-        <translation type="finished">Konfiguracioni i Barrier  (*.conf);;Te gjithe  (*.*)</translation>
+        <source>Barrier Configurations (*.conf)</source>
+        <translation type="finished">Konfiguracioni i Barrier (*.conf)</translation>
     </message>
     <message>
         <location filename="src/main.cpp" line="119"/>
