@@ -2,11 +2,11 @@
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
  * Copyright (C) 2008 Volker Lanz (vl@fidra.de)
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -58,7 +58,7 @@ ActionDialog::ActionDialog(QWidget* parent, ServerConfig& config, Hotkey& hotkey
     m_pGroupBoxScreens->setChecked(m_Action.haveScreens());
 
     int idx = 0;
-    foreach(const Screen& screen, serverConfig().screens())
+    for (const Screen& screen : serverConfig().screens()) {
         if (!screen.isNull())
         {
             QListWidgetItem *pListItem = new QListWidgetItem(screen.name());
@@ -72,6 +72,7 @@ ActionDialog::ActionDialog(QWidget* parent, ServerConfig& config, Hotkey& hotkey
 
             idx++;
         }
+    }
 }
 
 void ActionDialog::accept()
@@ -83,9 +84,10 @@ void ActionDialog::accept()
     m_Action.setType(m_pButtonGroupType->checkedId());
     m_Action.setHaveScreens(m_pGroupBoxScreens->isChecked());
 
-    m_Action.typeScreenNames().clear();
-    foreach(const QListWidgetItem* pItem, m_pListScreens->selectedItems())
-        m_Action.typeScreenNames().append(pItem->text());
+    m_Action.clearTypeScreenNames();
+    for (const QListWidgetItem* pItem : m_pListScreens->selectedItems()) {
+        m_Action.appendTypeScreenName(pItem->text());
+    }
 
     m_Action.setSwitchScreenName(m_pComboSwitchToScreen->currentText());
     m_Action.setSwitchDirection(m_pComboSwitchInDirection->currentIndex());
