@@ -18,10 +18,12 @@
 #pragma once
 
 #include <QObject>
+#include <string>
+#include "io/filesystem.h"
 
 class SslCertificate : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     explicit SslCertificate(QObject *parent = 0);
@@ -35,10 +37,7 @@ signals:
     void generateFinished();
 
 private:
-    bool runTool(const QStringList& args);
-    void generateFingerprint(const QString& certificateFilename);
+    void generate_fingerprint(const barrier::fs::path& cert_path);
 
-private:
-    QString m_ProfileDir;
-    QString m_ToolOutput;
+    bool is_certificate_valid(const barrier::fs::path& path);
 };
