@@ -19,10 +19,10 @@
 
 #define ARCH_INTERNET ArchInternetUnix
 
-#include "base/String.h"
+#include <string>
 
 class ArchInternetUnix {
 public:
-    String                get(const String& url);
-    String                urlEncode(const String& url);
+    std::string get(const std::string& url);
+    std::string urlEncode(const std::string& url);
 };
