@@ -1,11 +1,11 @@
 /*
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2013-2016 Symless Ltd.
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,10 +25,7 @@ class Mutex;
 
 class StreamChunker {
 public:
-    static void            sendFile(
-                            char* filename,
-                            IEventQueue* events,
-                            void* eventTarget);
+    static void sendFile(const char* filename, IEventQueue* events, void* eventTarget);
     static void            sendClipboard(
                             String& data,
                             size_t size,
@@ -37,7 +34,7 @@ public:
                             IEventQueue* events,
                             void* eventTarget);
     static void            interruptFile();
-    
+
 private:
     static bool            s_isChunkingFile;
     static bool            s_interruptFile;
