@@ -1,11 +1,11 @@
 /*
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2013-2016 Symless Ltd.
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -133,14 +133,20 @@ public:
     */
     Event::Type        outputShutdown();
 
+    /** Get input format error event type
+
+        This is sent when a stream receives an irrecoverable input format error.
+    */
+    Event::Type inputFormatError();
     //@}
-        
+
 private:
     Event::Type        m_inputReady;
     Event::Type        m_outputFlushed;
     Event::Type        m_outputError;
     Event::Type        m_inputShutdown;
     Event::Type        m_outputShutdown;
+    Event::Type m_inputFormatError;
 };
 
 class IpcClientEvents : public EventTypes {
@@ -159,7 +165,7 @@ public:
     Event::Type        messageReceived();
 
     //@}
-    
+
 private:
     Event::Type        m_connected;
     Event::Type        m_messageReceived;
@@ -179,7 +185,7 @@ public:
 
     //! Raised when the client disconnects from the server.
     Event::Type        disconnected();
-        
+
     //@}
 
 private:
@@ -198,7 +204,7 @@ public:
 
     //! Raised when we have created the client proxy.
     Event::Type        clientConnected();
-    
+
     //! Raised when a message is received through a client proxy.
     Event::Type        messageReceived();
 
@@ -242,7 +248,7 @@ public:
     event when a remote connection has been established.
     */
     Event::Type        connected();
-    
+
     //! Get secure connected event type
     /*!
      Returns the secure socket connected event type.  A secure socket sends
@@ -342,14 +348,14 @@ public:
 
     //! @name accessors
     //@{
-    
+
     //! Get accepted event type
     /*!
      Returns the accepted event type.  This is sent whenever a server
      accepts a client.
      */
     Event::Type        accepted();
-    
+
     //! Get connected event type
     /*!
     Returns the connected event type.  This is sent whenever a
@@ -419,7 +425,7 @@ public:
     Event::Type        failure();
 
     //@}
-        
+
 private:
     Event::Type        m_success;
     Event::Type        m_failure;
@@ -510,7 +516,7 @@ public:
     Event::Type        screenSwitched();
 
     //@}
-        
+
 private:
     Event::Type        m_error;
     Event::Type        m_connected;
@@ -529,16 +535,16 @@ public:
         m_reloadConfig(Event::kUnknown),
         m_forceReconnect(Event::kUnknown),
         m_resetServer(Event::kUnknown) { }
-        
+
     //! @name accessors
     //@{
-        
+
     Event::Type        reloadConfig();
     Event::Type        forceReconnect();
     Event::Type        resetServer();
 
     //@}
-        
+
 private:
     Event::Type        m_reloadConfig;
     Event::Type        m_forceReconnect;
@@ -565,7 +571,7 @@ public:
     Event::Type        keyRepeat();
 
     //@}
-        
+
 private:
     Event::Type        m_keyDown;
     Event::Type        m_keyUp;
@@ -589,7 +595,7 @@ public:
 
     //! @name accessors
     //@{
-    
+
     //!  button down event type.  Event data is ButtonInfo*.
     Event::Type        buttonDown();
 
@@ -677,7 +683,7 @@ public:
     to sleep or a user session is deactivated (fast user switching).
     */
     Event::Type        suspend();
-    
+
     //! Get resume event type
     /*!
     Returns the resume event type. This is sent whenever the system wakes
@@ -686,7 +692,7 @@ public:
     Event::Type        resume();
 
     //@}
-        
+
 private:
     Event::Type        m_error;
     Event::Type        m_shapeChanged;
@@ -722,7 +728,7 @@ public:
 
     //! Clipboard sending event type
     /*!
-    Returns the clipboard sending event type. This is used to send 
+    Returns the clipboard sending event type. This is used to send
     clipboard chunks.
     */
     Event::Type        clipboardSending();
