@@ -2,11 +2,11 @@
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
  * Copyright (C) 2012 Nick Bolton
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -50,7 +50,7 @@ public:
     virtual void        close();
     virtual void        show(bool showIfEmpty);
     virtual bool        write(ELevel level, const char* message);
-    
+
     //! @name manipulators
     //@{
 
@@ -76,23 +76,23 @@ public:
     when threaded mode is on.
     */
     void                sendBuffer();
-    
+
     //@}
-    
+
     //! @name accessors
     //@{
-    
+
     //! Get the buffer size
     /*!
     Returns the maximum size of the buffer.
     */
     UInt16                bufferMaxSize() const;
-    
+
     //@}
 
 private:
     void                init();
-    void                bufferThread(void*);
+    void buffer_thread();
     std::string getChunk(size_t count);
     void appendBuffer(const std::string& text);
     bool                isRunning();
