@@ -2,11 +2,11 @@
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
  * Copyright (C) 2003 Chris Schoeneman
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -169,7 +169,7 @@ private:
 	typedef std::vector<HKL> GroupList;
 
 	// send ctrl+alt+del hotkey event on NT family
-	static void			ctrlAltDelThread(void*);
+    static void ctrl_alt_del_thread();
 
 	bool				getGroups(GroupList&) const;
 	void				setWindowGroup(SInt32 group);
