@@ -2,11 +2,11 @@
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
  * Copyright (C) 2002 Chris Schoeneman
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -64,8 +64,8 @@ private:
     void                watchDesktop();
     void                watchProcess(HANDLE process);
     void                unwatchProcess();
-    void                watchDesktopThread(void*);
-    void                watchProcessThread(void*);
+    void watch_desktop_thread();
+    void watch_process_thread();
 
     void                setSecure(bool secure, bool saveSecureAsInt);
     bool                isSecure(bool* wasSecureAnInt) const;
