@@ -2,11 +2,11 @@
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
  * Copyright (C) 2002 Chris Schoeneman
- * 
+ *
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- * 
+ *
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -37,7 +37,7 @@ public:
     PrimaryClient(const std::string& name, barrier::Screen* screen);
     ~PrimaryClient();
 
-#ifdef TEST_ENV
+#ifdef BARRIER_TEST_ENV
     PrimaryClient() : BaseClientProxy("") { }
 #endif
 
@@ -96,12 +96,12 @@ public:
     the edges of the screen, typically the center.
     */
     void                getCursorCenter(SInt32& x, SInt32& y) const;
-    
+
     //! Get toggle key state
     /*!
     Returns the primary screen's current toggle modifier key state.
     */
-    virtual KeyModifierMask        
+    virtual KeyModifierMask
                         getToggleMask() const;
 
     //! Get screen lock state
