@@ -16,7 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#define TEST_ENV
+#define BARRIER_TEST_ENV
 
 #include "test/mock/barrier/MockKeyMap.h"
 #include "test/mock/barrier/MockEventQueue.h"
